@@ -6,7 +6,7 @@ use warnings;
 no warnings qw(uninitialized);
 
 package Apache::Wyrd::Input::Condenser;
-our $VERSION = '0.81';
+our $VERSION = '0.82';
 use base qw(Apache::Wyrd::Input::Complex);
 use Apache::Wyrd::Services::SAK qw(token_parse);
 
@@ -14,7 +14,7 @@ use Apache::Wyrd::Services::SAK qw(token_parse);
 
 =head1 NAME
 
-Apache::Wyrd::Input::Condenser
+Apache::Wyrd::Input::Condenser - Use Wyrd Inputs/Sets as sub-Input Wyrds
 
 =head1 SYNOPSIS
 
